@@ -4,6 +4,7 @@ author: Maikel Punie <maikel.punie@gmail.com>
 from __future__ import annotations
 
 import string
+from typing import Any, Callable
 
 from velbusaio.command_registry import commandRegistry
 from velbusaio.const import (
@@ -144,9 +145,21 @@ class Channel:
         # COMPONENT_TYPES = ["switch", "sensor", "binary_sensor", "cover", "climate", "light"]
         return []
 
-    def on_status_update(self, meth: type) -> None:
+    def on_status_update(self, meth: Callable) -> None:
         self._on_status_update.append(meth)
 
+    def get_counter_state(self):
+        raise NotImplementedError
+
+    def get_counter_unit(self):
+        raise NotImplementedError
+
+    def get_max(self) -> int:
+        raise NotImplementedError
+
+    def get_min(self) -> int:
+        raise NotImplementedError
+
 
 class Blind(Channel):
     """
@@ -159,7 +172,7 @@ class Blind(Channel):
     def get_categories(self) -> list:
         return ["cover"]
 
-    def get_position(self) -> str:
+    def get_position(self) -> int:
         return self._position
 
     def get_state(self) -> str:
@@ -382,8 +395,14 @@ class Temperature(Channel):
     _cur = 0
     _max = None
     _min = None
+    _target = 0
+    _cmode = None
+    _cstatus = None
+    _thermostat = False
 
     def get_categories(self) -> list:
+        if self._thermostat:
+            return ["sensor", "climate"]
         return ["sensor"]
 
     def get_class(self) -> str:
@@ -408,6 +427,43 @@ class Temperature(Channel):
             return None
         return round(self._min, 2)
 
+    def get_climate_target(self) -> int:
+        return round(self._target, 2)
+
+    def get_climate_preset(self) -> str:
+        return self._cmode
+
+    def get_climate_mode(self) -> str:
+        return self._cstatus
+
+    async def set_temp(self, temp) -> None:
+        cls = commandRegistry.get_command(0xE4, self._module.get_type())
+        msg = cls(self._address)
+        msg.temp = temp * 2
+        await self._writer(msg)
+
+    async def set_preset(self, mode) -> None:
+        if mode == "safe":
+            code = 0xDE
+        elif mode == "comfort":
+            code = 0xDB
+        elif mode == "day":
+            code = 0xDC
+        elif mode == "night":
+            code = 0xDD
+        cls = commandRegistry.get_command(code, self._module.get_type())
+        msg = cls(self._address)
+        await self._writer(msg)
+
+    async def set_mode(self, mode) -> None:
+        if mode == "heat":
+            code = 0xE0
+        elif mode == "cool":
+            code = 0xDF
+        cls = commandRegistry.get_command(code, self._module.get_type())
+        msg = cls(self._address)
+        await self._writer(msg)
+
 
 class SensorNumber(Channel):
     """
@@ -525,33 +581,3 @@ class Memo(Channel):
                 msg = cls(self._address)
                 msg.start = msgcntr
         await self._writer(msg)
-
-
-# _mode = None
-# _target = None
-# _cur = None
-#
-# def get_categories(self):
-#    return ["climate"]
-#
-# async def set_temp(self, temp) -> None:
-#    cls = commandRegistry.get_command(0xE4, self._module.get_type())
-#    msg = cls(self._address)
-#    msg.temp = temp * 2
-#    await self._writer(msg)
-#
-# async def set_mode(self, mode) -> None:
-#    if mode == "safe":
-#        code = 0xDE
-#    elif mode == "comfort":
-#        code = 0xDB
-#    elif mode == "day":
-#        code = 0xDC
-#    elif mode == "night":
-#        code = 0xDD
-#    cls = commandRegistry.get_command(code, self._module.get_type())
-#    msg = cls(self._address)
-#    await self._writer(msg)
-#
-# def get_state(self) -> int:
-#    return round(self._cur, 2)
