@@ -4,6 +4,7 @@ Velbus packet handler
 """
 from __future__ import annotations
 
+import asyncio
 import json
 import logging
 import re
@@ -11,11 +12,11 @@ import re
 import pkg_resources
 
 from velbusaio.command_registry import commandRegistry
-from velbusaio.const import RTR
 from velbusaio.helpers import h2, keys_exists
 from velbusaio.message import Message
 from velbusaio.messages.module_subtype import ModuleSubTypeMessage
 from velbusaio.messages.module_type import ModuleTypeMessage
+from velbusaio.raw_message import RawMessage
 
 
 class PacketHandler:
@@ -28,6 +29,7 @@ class PacketHandler:
         self._writer = writer
         self._velbus = velbus
         self._scan_complete = False
+        self._scan_complete_event = asyncio.Event()
         with open(
             pkg_resources.resource_filename(__name__, "moduleprotocol/protocol.json")
         ) as protocol_file:
@@ -35,31 +37,36 @@ class PacketHandler:
 
     def scan_finished(self) -> None:
         self._scan_complete = True
+        self._scan_complete_event.set()
+        self._log.debug("Scan complete")
 
     def scan_started(self) -> None:
         self._scan_complete = False
+        self._scan_complete_event.clear()
 
-    async def handle(self, data: str) -> None:
+    async def handle(self, rawmsg: RawMessage) -> None:
         """
         Handle a received packet
         """
-        priority = data[1]
-        address = int(data[2])
-        rtr = data[3] & RTR == RTR
-        data_size = data[3] & 0x0F
-        command_value = data[4]
-        if data_size < 1:
+        if rawmsg.address < 1 or rawmsg.address > 254:
             return
-        if address < 1 or address > 254:
+        if rawmsg.command is None:
             return
+
+        priority = rawmsg.priority
+        address = rawmsg.address
+        rtr = rawmsg.rtr
+        command_value = rawmsg.command
+        data = rawmsg.data_only
+
         if command_value == 0xFF and not self._scan_complete:
             msg = ModuleTypeMessage()
-            msg.populate(priority, address, rtr, data[5:-2])
+            msg.populate(priority, address, rtr, data)
             self._log.debug(f"Received {msg}")
             await self._handle_module_type(msg)
         elif command_value == 0xB0 and not self._scan_complete:
             msg = ModuleSubTypeMessage()
-            msg.populate(priority, address, rtr, data[5:-2])
+            msg.populate(priority, address, rtr, data)
             self._log.debug(f"Received {msg}")
             await self._handle_module_subtype(msg)
         elif command_value in self.pdata["MessagesBroadCast"]:
@@ -73,7 +80,7 @@ class PacketHandler:
             if commandRegistry.has_command(int(command_value), module_type):
                 command = commandRegistry.get_command(command_value, module_type)
                 msg = command()
-                msg.populate(priority, address, rtr, data[5:-2])
+                msg.populate(priority, address, rtr, data)
                 self._log.debug(f"Received {msg}")
                 # send the message to the modules
                 await (self._velbus.get_module(msg.address)).on_message(msg)
